{% extends 'blank_with_menu.html' %}


{% block title %}About{% end %}


{% block content %}
<p>
    <b>pyspectator-tornado</b> project is example of usage
    <a href="https://github.com/opium999/pyspectator">pyspectator</a>
    python module as a part of web-application.

    More detail about project you can read on
    <a href="https://github.com/uzumaxy/pyspectator-tornado">github</a>.
</p>
<p>
    Site is based on tornado web-framework and use
    <a href="http://getbootstrap.com/">bootstrap</a>
    <a href="http://startbootstrap.com/sb-admin-v2">sb-admin-v2</a> template.
</p>
<p>
    <ul class="list-inline">
        <li>
            <b>Author:</b>
            <a href="uzumaxy.tk">Maxim Grischuk</a>
        </li>
        <li>
            <b>License:</b>
            <a href="https://raw.githubusercontent.com/uzumaxy/pyspectator-tornado/master/LICENSE">BSD</a>
        </li>
    </ul>
</p>
{% end %}