{% extends '../blank_with_menu.html' %}


{% block title %}CPU{% end %}


{% block content %}
<dl class="dl-horizontal">
    <dt>Name</dt>
    <dd>{{ cpu['name'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Amount of cores</dt>
    <dd>{{ cpu['count'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Load</dt>
    <dd>
        <span id="load">{{ cpu['load'] }}</span>%
    </dd>
</dl>

<div class="panel panel-default">
    <div class="panel-heading">
        CPU load
    </div>
    <!-- /.panel-heading -->
    <div class="panel-body">
        <div class="flot-chart">
            <div class="flot-chart-content" id="cpu-load-chart"></div>
        </div>
    </div>
    <!-- /.panel-body -->
</div>
<!-- /.panel -->
{% end %}


{% block js %}
<!-- Plugin Scripts - Flot -->
<!--[if lte IE 8]>
<script src="{{ static_url('js/plugins/flot/excanvas.min.js') }}"></script>
<![endif]-->
<script src="{{ static_url('js/plugins/flot/jquery.flot.min.js') }}"></script>

<!-- Page-Level Script -->
<script src="{{ static_url('js/monitor/cpu.js') }}"></script>
{% end %}
