{% extends '../blank_with_menu.html' %}


{% block title %}Profile{% end %}


{% block content %}
<dl class="dl-horizontal">
    <dt>Login</dt>
    <dd>username</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Group</dt>
    <dd>Administrator</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Last login</dt>
    <dd>15:10:10 12.06.2014</dd>
</dl>
{% end %}
