{% extends '../blank_with_menu.html' %}


{% block title %}Network{% end %}


{% block content %}
<dl class="dl-horizontal">
    <dt>Hostname</dt>
    <dd>{{ network['hostname'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>MAC address</dt>
    <dd>{{ network['mac_address'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>IP address</dt>
    <dd>{{ network['ip_address'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Mask</dt>
    <dd>{{ network['mask'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Gateway</dt>
    <dd>{{ network['gateway'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Bytes sent</dt>
    <dd id="bytes_sent">{{ network['bytes_sent'] }}</dd>
</dl>
<dl class="dl-horizontal">
    <dt>Bytes received</dt>
    <dd id="bytes_recv">{{ network['bytes_recv'] }}</dd>
</dl>
{% end %}


{% block js %}
<!-- Page-Level Script -->
<script src="{{ static_url('js/monitor/network.js') }}"></script>
{% end %}